@@ -1,7 +1,7 @@
 package File::RsyBak;
 
-our $DATE = '2015-03-18'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-04-22'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -382,7 +382,7 @@ File::RsyBak - Backup files/directories with histories, using rsync
 
 =head1 VERSION
 
-This document describes version 0.24 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-03-18.
+This document describes version 0.25 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-04-22.
 
 =head1 SYNOPSIS
 
@@ -393,11 +393,24 @@ From your Perl program:
      source    => '/path/to/mydata',
      target    => '/backup/mydata',
      histories => [-7, 4, 3],         # 7 days, 4 weeks, 3 months
+     extra_rsync_opts => [qw/--exclude Cache --exclude cache --exclude tmp --exclude temp/],
  );
 
 Or, just use the provided script from the command-line:
 
- % rsybak --source /path/to/mydata --target /backup/mydata
+ % rsybak --source /path/to/mydata --target /backup/mydata --extra-rsync-opts-json '["--exclude","Cache","--exclude","cache","--exclude","tmp","--exclude","temp"]'
+
+Or, if you have this configuration in C</etc/rsybak.conf> or <~/rsybak.conf>:
+
+ [system]
+ source = /path/to/mydata
+ target = /backup/mydata
+ ; also specify as JSON
+ extra_rsync_opts = ["--exclude","Cache","--exclude","cache","--exclude","tmp","--exclude","temp"]
+
+you can just run:
+
+ % rsybak --config-profile system
 
 Example resulting backup (after several runs so that backup history has
 accumulated):
@@ -524,7 +537,7 @@ Extra options to pass to rsync command when doing backup. Note that the options
 will be shell quoted, , so you should pass it unquoted, e.g. ['--exclude',
 '/Program Files'].
 
-=item * B<histories> => I<array[int]> (default: [-7, 4, 3])
+=item * B<histories> => I<array[int]> (default: [-7,4,3])
 
 Histories/history levels.
 
